_print_fmt

Function _print_fmt 

unsafe fn _print_fmt(fmt: &mut Formatter<'_>, print_fmt: PrintFmt) -> Result
Safety

This function is not Sync. The caller must hold a mutex lock, or there must be only one thread in the program.